# Munibot

![Tests](https://github.com/amercader/munibot/workflows/Tests/badge.svg)

Munibot is friendly Twitter bot that posts aerial or satellite imagery of administrative regions (tipically municipalities).


![munis_cat_scaled](https://user-images.githubusercontent.com/200230/102014660-6328cf00-3d57-11eb-86ec-183e8512538b.jpg)

It is written in a modular way so it's easy to customize to different data sources, via the implementation of profiles.

It currently powers the following Twitter accounts:

* [@munibot_es](https://twitter.com/munibot_es): All municipalities in Spain, shown in random order, with base aerial ortophotograhy from [PNOA IGN](https://pnoa.ign.es/).

* [@munibot_cat](https://twitter.com/munibot_cat): All municipalities in Catalonia, shown in random order, with base aerial ortophotograhy from [ICGC](https://www.icgc.cat/ca/Administracio-i-empresa/Medi-natural/Imatges-aeries-i-de-satel-lit/Ortofoto-convencional).


Here's how a sample tweet looks like:

<p align="center">

![example_tweet](https://user-images.githubusercontent.com/200230/102015071-89e80500-3d59-11eb-8685-12967e9276d8.jpg)

</p>

## License

[MIT](/amercader/munibot/blob/master/LICENSE.txt)
